@@ -12,7 +12,7 @@ class CannotConnect(AmazonError):
 
 
 class CannotAuthenticate(AmazonError):
-    """Exception raised when credentials are incorrect."""
+    """Exception raised when authentication fails."""
 
 
 class CannotRetrieveData(AmazonError):
@@ -25,7 +25,3 @@ class CannotRegisterDevice(AmazonError):
 
 class WrongMethod(AmazonError):
     """Exception raised when the wrong login metho is used."""
-
-
-class WrongCountry(AmazonError):
-    """Exceptio nraised when Amazon country."""
